@@ -1079,9 +1079,8 @@ function decore_select2 (data) {
 
 function load_date_range(instance, format='DD/MM/YYYY') {
     var options = {
-        'startDate': moment().startOf('hour'),
-        'endDate': moment().startOf('hour').add(32, 'hour'),
-        'locale': {
+        'autoUpdateInput': false,
+         'locale': {
             format: format,
         }
     };
@@ -1092,6 +1091,7 @@ function load_date_range(instance, format='DD/MM/YYYY') {
     }
     return options;
 }
+
 function load_datetime_range(instance, format='DD/MM/YYYY HH:mm A') {
     var options = {
         'timePicker': true,
@@ -1116,6 +1116,7 @@ function load_datetime_range(instance, format='DD/MM/YYYY HH:mm A') {
     }
     return options;
 }
+
 function load_date_range_custom(instance, format='DD/MM/YYYY') {
     var options = {
         startDate: moment().startOf('hour'),
@@ -1150,6 +1151,7 @@ function load_date_range_custom(instance, format='DD/MM/YYYY') {
     }
     return options;
 }
+
 function grid_slider(instance) {
     let obj = $(instance[0]);
 
